@@ -9,21 +9,18 @@ from bs4.element import Tag
 from .base import BaseClass
 
 
-class CheckTagMixin:
-    """Mixin for _check_tag method"""
-    @staticmethod
-    def _check_tag(tag: Tag):
-        """Checks if tag is valid for usage"""
-        raise NotImplementedError("`_check_tag` Not implemented")
-
-
-class BaseTag(BaseClass, CheckTagMixin):
+class BaseTag(BaseClass):
     """Base Tag Class for parsing BS4 tags from responses"""
     @classmethod
     def from_tag(cls, tag):
         """Checks tag and returns initialized object"""
         raise NotImplementedError("`from_tag` Not implemented")
 
+    @staticmethod
+    def _check_tag(tag: Tag):
+        """Checks if tag is valid for usage"""
+        raise NotImplementedError("`_check_tag` Not implemented")
+
 
 @define
 class Faculty(BaseTag):
@@ -162,6 +159,7 @@ class BaseLesson(BaseTag):
     teacher: dict = {}
     lesson_name: dict = {}
     lesson_info: str = ""
+    auditorium: str | None = None
 
     @staticmethod
     def _check_tag(tag: Tag):
@@ -177,47 +175,6 @@ class BaseLesson(BaseTag):
         )
 
 
-class AllTimeLesson(BaseLesson):
-    """
-        This class should be used to parse lesson from bs4 tag
-        If you are getting schedule for all time
-    """
-    @classmethod
-    def from_tag(cls, tag):
-        obj = cls()
-        obj.lesson_tag = tag
-        obj.parse_tag()
-        return obj
-
-    def parse_tag(self):
-        lesson = self.lesson_tag
-        self.lesson_date = lesson.text
-        predm = lesson.nextSibling
-        self.lesson_name = {
-            'short': predm.text,
-            'full': predm.attrs.get('title', "Not Set")
-        }
-        prp = predm.nextSibling
-        if isinstance(prp, str):
-            # <br> may be interpreted as '\n'
-            prp = prp.nextSibling
-        self.teacher = {
-            'short': prp.text.replace('\xa0', ' '),  # Why...
-            'full': prp.attrs.get('title', "Not Set")
-        }
-        card = prp.nextSibling
-        if isinstance(card, str):
-            # <br> may be interpreted as '\n'
-            card = card.nextSibling
-        card_content: Tag = card.find(
-            attrs={
-                'class': 'card-content'
-            }
-        )
-        if card_content:
-            self.lesson_info = card_content.text.replace('\t', '')
-
-
 class RegularLesson(BaseLesson):
     """
         This class should be used to parse lesson from bs4 tag
@@ -231,32 +188,57 @@ class RegularLesson(BaseLesson):
         return obj
 
     def parse_tag(self):
-        lesson = self.lesson_tag
-        # I don't know why, but ok :)
-        skip = lesson.nextSibling
-        self.lesson_name = {
-            'short': lesson.text,
-            'full': lesson.attrs.get('title', "Not Set")
-        }
-        prp = skip.nextSibling
-        if isinstance(prp, str):
-            # <br> may be interpreted as '\n'
-            prp = prp.nextSibling
-        self.teacher = {
-            'short': prp.text.replace('\xa0', ' '),  # Why...
-            'full': prp.attrs.get('title', "Not Set")
-        }
-        card = prp.nextSibling
-        if isinstance(card, str):
-            # <br> may be interpreted as '\n'
-            card = card.nextSibling
-        card_content: Tag = card.find(
+        lesson_top = self.lesson_tag.parent
+
+        predm_element = lesson_top.find(
+            name='span',
             attrs={
-                'class': 'card-content'
+                'class': 'predm'
             }
         )
-        if card_content:
-            self.lesson_info = card_content.text.replace('\t', '')
+        self.lesson_name = {
+            'short': predm_element.text,
+            'full': predm_element.attrs.get('title', "Not Set")
+        }
+
+        prp_element = lesson_top.find(
+            name='span',
+            attrs={
+                'class': 'prp'
+            }
+        )
+        self.teacher = {
+            'short': prp_element.text.replace('\xa0', ' '),  # Why...
+            'full': prp_element.attrs.get('title', "Not Set")
+        }
+
+        # Card tag consists of two children
+        # First states type of content
+        # Other - content itself
+        card_tag = lesson_top.find(
+            name='div',
+            attrs={
+                'class': 'card'
+            }
+        )
+        if card_tag:
+            card_content = card_tag.find(
+                name='div',
+                attrs={
+                    'class': 'card-content'
+                }
+            )
+            if card_content:
+                self.lesson_info = card_content.text.replace('\t', '').strip()
+
+        auditorium_tag = lesson_top.find(
+            name='a',
+            attrs={
+                'class': 'fg-blue'
+            }
+        )
+        if auditorium_tag:
+            self.auditorium = auditorium_tag.text
 
 
 class Pair(BaseTag):
@@ -321,8 +303,9 @@ class Pair(BaseTag):
     @staticmethod
     def get_lessons(pair: Tag):
         """Parses lessons for this pair"""
-        # All dates have this class
+        # All time 'days' have <span>s with dates in them
         all_dates = pair.find_all(
+            name='span',
             attrs={
                 'class': 'fg-blue'
             }
@@ -339,9 +322,10 @@ class Pair(BaseTag):
             return lessons
         if len(all_dates) > 0:
             # This means we are dealing with 'all time' records
+            # Which have multiple lessons per pair
             for lesson in all_dates:
                 lessons.append(
-                    AllTimeLesson.from_tag(
+                    RegularLesson.from_tag(
                         lesson
                     )
                 )
