@@ -5,34 +5,26 @@ from selenium import webdriver
 from selenium.webdriver import FirefoxOptions
 
 from .base import BaseClass
-
-
-class RequestsEnum:
-    """Contains information for Requests library"""
-    class Methods:
-        """Conains used HTTP Methods for requests"""
-        GET = 'GET'
-        POST = 'POST'
-
-        CHOICES = [
-            GET, POST
-        ]
-
-    class Codes:
-        """Contains used HTTP response codes"""
-        OK = 200
-
+from .enums import RequestsEnum
 
 class TTLValue(BaseClass):
     """Describes value with some time to live (like authorization token)"""
-    _ttl: int = 3600
+    _ttl: int = 1800  # Time To Live (in seconds)
     _value: object = None
 
     issued_at: datetime = datetime.min
 
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.issued_at = datetime.now()
+
     def is_valid(self):
-        """Checks wether value is still valid (compares ttl to current time)"""
-        if (datetime.now() - self.issued_at).seconds > self._ttl:
+        """
+            Checks wether value is still valid
+                True if TTLValue was issued less seconds before than Time To Live
+        """
+        seconds_passed = (datetime.now() - self.issued_at).seconds
+        if seconds_passed < self._ttl:
             return True
         return False
 
@@ -46,7 +38,8 @@ class TTLValue(BaseClass):
 class Cookies(TTLValue):
     """Describes cookies (Temporary values) for requests"""
 
-    def __init__(self, sender):
+    def __init__(self, sender, *args, **kwargs):
+        super().__init__(*args, **kwargs)
         self.sender: Sender = sender
 
     @property
@@ -55,6 +48,7 @@ class Cookies(TTLValue):
         if self._value and self.is_valid():
             return self._value
 
+        print("Cookies are being updated")
         cookie = self.get_cookie()
         if not cookie:
             raise RuntimeError("Could not get cookies")
@@ -75,8 +69,7 @@ class Cookies(TTLValue):
         key = 'PHPSESSID'
         cookie = response.cookies.get(key)
 
-        self._value = {key: cookie, 'notbot': notbot}
-        return self._value
+        return self.set_value({key: cookie, 'notbot': notbot})
 
 
 class NotBot(TTLValue):
@@ -105,6 +98,7 @@ class NotBot(TTLValue):
         if self._value and self.is_valid():
             return self._value
 
+        print("Notbot is being updated")
         notbot = self.get_notbot()
         if not notbot:
             raise RuntimeError("Could not get notbot")
@@ -147,9 +141,9 @@ class Sender(BaseClass):
     def send_request(self, method: str, data: (dict | None) = None):
         """Sends request with method and some data, if needed"""
         session = requests.Session()
-        if method not in RequestsEnum.Methods.CHOICES:
+        if method not in RequestsEnum.Methods.CHOICES.value:
             raise ValueError(
-                f'arg. `method` should be one of: {RequestsEnum.Methods.CHOICES}',
+                f'arg. `method` should be one of: {RequestsEnum.Methods.CHOICES.value}',
                 method,
             )
 
@@ -166,7 +160,7 @@ class Sender(BaseClass):
                 self.link,
                 exception
             ) from exception
-        if response.status_code != RequestsEnum.Codes.OK:
+        if response.status_code != RequestsEnum.code_ok():
             raise ValueError(
                 'server returned non OK response',
                 response.status_code,
